#ifndef SIMPLECUBE_H
#define SIMPLECUBE_H

#include <e32base.h> // for CBase definition
#include <GLES/gl.h> // OpenGL ES header file

// Enumerated rendering mode for triangle and triangle fan based rendering.
typedef enum { ETriangles, ETriangleFans } TRenderingMode;

// MACROS
#define FRUSTUM_LEFT   -1.f     //left vertical clipping plane
#define FRUSTUM_RIGHT   1.f     //right vertical clipping plane
#define FRUSTUM_BOTTOM -1.f     //bottom horizontal clipping plane
#define FRUSTUM_TOP     1.f     //top horizontal clipping plane
#define FRUSTUM_NEAR    3.f     //near depth clipping plane
#define FRUSTUM_FAR  1000.f     //far depth clipping plane

class CSimpleCube : public CBase
    {
    public:  // Constructors and destructor

         // Factory method for creating a new CSimpleCube object.
        static CSimpleCube* NewL( TUint aWidth, TUint aHeight);
         // Destructor. Does nothing.
        virtual ~CSimpleCube();

         // Initializes OpenGL ES, sets the vertex and color
         // arrays and pointers. Also selects the shading mode.
        void AppInit( void );
         // Called upon application exit. Does nothing.
        void AppExit( void );

        void DrawBox( GLfloat aSizeX, GLfloat aSizeY, GLfloat aSizeZ );

        /**
         * Renders one frame.
         * @param aFrame Number of the frame to be rendered.
         */
        void AppCycle( TInt aFrame );

         //Sets the shading mode to flat.
        void FlatShading( void );

         // Sets the shading to smooth (gradient).
        void SmoothShading( void );

         //Sets the rendering to use triangles.
        void TriangleMode( void );

        //Sets the rendering to use triangle fans.
        void TriangleFanMode( void );

        void WhiteBG( void );
        void BlackBG( void );
        
        //Resize func
        void SetScreenSize( TUint aWidth, TUint aHeight );

    protected: // New functions

         // Standard constructor that must never Leave.
         // Stores the given screen width and height.
        CSimpleCube( TUint aWidth, TUint aHeight);

         // Second phase contructor. Does nothing.
        void ConstructL( void );

    private: // Data

        TUint           iScreenWidth;
        TUint           iScreenHeight;
        TRenderingMode  iDrawingMode;
    };
    
#endif // SIMPLECUBE_H
