/*
 * ==============================================================================
 *  Name        : SimpleCubeAppUi.cpp
 *  Part of     : OpenGLEx / SimpleCube
 *
 *  Copyright (c) 2004-2006 Nokia Corporation.
 *  This material, including documentation and any related
 *  computer programs, is protected by copyright controlled by
 *  Nokia Corporation.
 * ==============================================================================
 */


// INCLUDE FILES
#include "SimpleCubeAppUi.h"
#include "SimpleCubeContainer.h"
#include <SimpleCube.rsg>
#include "simplecube.hrh"

#include <avkon.hrh>

// ================= MEMBER FUNCTIONS =======================
//
// ----------------------------------------------------------
// CSimpleCubeAppUi::ConstructL()
// ----------------------------------------------------------
//
void CSimpleCubeAppUi::ConstructL()
    {
    BaseConstructL();
    iAppContainer = new (ELeave) CSimpleCubeContainer;
    iAppContainer->SetMopParent(this);
    iAppContainer->ConstructL( ClientRect() );
    AddToStackL( iAppContainer );
    }

// ----------------------------------------------------
// CSimpleCubeAppUi::~CSimpleCubeAppUi()
// Destructor
// Frees reserved resources
// ----------------------------------------------------
//
CSimpleCubeAppUi::~CSimpleCubeAppUi()
{
    if ( iAppContainer )
        {
        RemoveFromStack( iAppContainer );
        delete iAppContainer;
        }
}

// ------------------------------------------------------------------------------
// CSimpleCubeAppUi::::DynInitMenuPaneL(TInt aResourceId,CEikMenuPane* aMenuPane)
//  This function is called by the EIKON framework just before it displays
//  a menu pane. Its default implementation is empty, and by overriding it,
//  the application can set the state of menu items dynamically according
//  to the state of application data.
// ------------------------------------------------------------------------------
//
void CSimpleCubeAppUi::DynInitMenuPaneL(
    TInt /*aResourceId*/,CEikMenuPane* /*aMenuPane*/)
    {
    }

// ----------------------------------------------------
// CSimpleCubeAppUi::HandleKeyEventL(
//     const TKeyEvent& aKeyEvent,TEventCode /*aType*/)
// Key event handler
// ----------------------------------------------------
//
TKeyResponse CSimpleCubeAppUi::HandleKeyEventL(
    const TKeyEvent& aKeyEvent ,TEventCode aType)
{

	switch ( aKeyEvent.iCode )
	{
		case EKeyLeftArrow:
			iAppContainer->iSimpleCube->BlackBG();
		break;
		
		case EKeyRightArrow:
			iAppContainer->iSimpleCube->WhiteBG();
		break;
		
		default:
			return EKeyWasNotConsumed;
		break;
	}

	return EKeyWasConsumed;
}

// ----------------------------------------------------
// CSimpleCubeAppUi::HandleCommandL(TInt aCommand)
// Command handler
// ----------------------------------------------------
//
void CSimpleCubeAppUi::HandleCommandL(TInt aCommand)
    {
    switch ( aCommand )
        {
        case EAknSoftkeyBack:
	        case EEikCmdExit:          
	            Exit();
	            break;    
	        case ESimpleCubeFlat:
	            iAppContainer->iSimpleCube->FlatShading();
	            break;
	        case ESimpleCubeSmooth:
	            iAppContainer->iSimpleCube->SmoothShading();
	            break;
	        case ESimpleCubeTriangles:
	            iAppContainer->iSimpleCube->TriangleMode();
	            break;
	        case ESimpleCubeTriangleFans:
	            iAppContainer->iSimpleCube->TriangleFanMode();
	            break;
    	break;
  
        default:
            break;
        }
    }

// End of File
